@@ -1,6 +1,8 @@
 /* graphene-vectors-private.h: Private vector definitions
  *
- * Copyright © 2014  Emmanuele Bassi
+ * SPDX-License-Identifier: MIT
+ *
+ * Copyright 2014  Emmanuele Bassi
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -21,8 +23,7 @@
  * THE SOFTWARE.
  */
 
-#ifndef __GRAPHENE_VECTORS_PRIVATE_H__
-#define __GRAPHENE_VECTORS_PRIVATE_H__
+#pragma once
 
 #include "graphene-types.h"
 
@@ -31,5 +32,3 @@
 #include "graphene-vec4.h"
 
 #include "graphene-simd4f.h"
-
-#endif /* __GRAPHENE_VECTORS_PRIVATE_H__ */
